==> cogen-0.1.3.zip: cogen-0.1.3/cogen/__init__.py <==
# -*- coding: utf-8 -*-
'''
This is a library for network oriented, coroutine based programming. 
The interfaces and events/operations aim to mimic thread features. Coroutines 
work as simple generators, the operations and events work as objects passed in 
and out of the generator, these objects are managed by the scheduler/network poller. 

Check each modules for specific help.
'''

__license__ = '''
Copyright (c) 2007, Mărieş Ionel Cristian

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
'''

__author__ = "Mărieş Ionel Cristian"
__email__ = "ionel.mc at gmail dot com"
__revision__ = "$Revision: 64 $"
__version__ = '0.1.3'
__svnid__ = "$Id: __init__.py 64 2007-12-25 16:18:12Z ionel.mc $"

from cogen import core
from cogen import common
from cogen import web

==> cogen-0.1.6.zip: cogen-0.1.6/cogen/__init__.py <==
# -*- coding: utf-8 -*-
'''
This is a library for network oriented, coroutine based programming. 
The interfaces and events/operations aim to mimic thread features. Coroutines 
work as simple generators, the operations and events work as objects passed in 
and out of the generator, these objects are managed by the scheduler/network 
poller. 

Check each modules for specific help.
'''

__license__ = '''
Copyright (c) 2007, Mărieş Ionel Cristian

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
'''

__author__ = "Mărieş Ionel Cristian"
__email__ = "ionel dot mc at gmail dot com"
__revision__ = "$Revision: 202 $"
__version__ = '0.1.6'
__svnid__ = "$Id: __init__.py 202 2008-02-23 17:47:48Z ionel.mc $"

from cogen import core
from cogen import common
from cogen import web
